@@ -15,7 +15,7 @@ else
 	MODULE=$(echo "${OWNER}/${DIR}" | sed 's/^\/*//')
 	TMP="`mktemp -t -d`"
 	git clone --bare "https://github.com/${MODULE}.git" "${TMP}"
-	REV="$(git --git-dir "${TMP}" describe --tags --long master | sed -e 's/^v*//' -e 's/-/+/g')"
+	REV="$(git --git-dir "${TMP}" describe --exclude nightly-build --tags --long master | sed -e 's/^v*//' -e 's/-/+/g')"
 	LONGREV="$(git --git-dir "${TMP}" rev-parse master)"
 	TARNAME="${DIR}_${REV}.orig.tar"
 	echo "${LONGREV}"
